@@ -37,7 +37,7 @@ use Params::Validate qw(:all);
 use Module::Find qw( );
 
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
 use overload
   '%{}' => '_envhash',
@@ -92,7 +92,7 @@ BEGIN {
     if ( ! exists $ENV{APP_ENV_SITE} && _existsModule('App::Env::Site') )
     {
         eval { require App::Env::Site };
-        croak( "Error loading App::Env::Site: $@\n" ) if $@;
+        croak( ref $@ ? $@ : "Error loading App::Env::Site: $@\n" ) if $@;
     }
 }
 
@@ -921,7 +921,8 @@ sub new
 
 	( $self->{module}, my $app_opts )
           = eval { App::Env::_require_module( $self->{app}, $self->{opt}{Site} ) };
-        croak( "error loading application environment module for $self->{app}:\n", $@ )
+
+        croak( ref $@ ? $@ : "error loading application environment module for $self->{app}:\n", $@ )
           if $@;
 
         die( "application environment module for $self->{app} does not exist\n" )
@@ -1015,16 +1016,14 @@ sub load {
 
     my $envs;
     my $fenvs = $module->can('envs' );
-    if ( $fenvs )
-    {
-	$envs = eval { $fenvs->( $self->{opt}{AppOpts} ) };
-	croak( "error in ${module}::envs: $@\n" )
-	  if $@;
-    }
-    else
-    {
-        croak( "$module does not have an 'envs' function\n" );
-    }
+
+    croak( "$module does not have an 'envs' function\n" )
+      unless $fenvs;
+
+    $envs = eval { $fenvs->( $self->{opt}{AppOpts} ) };
+
+    croak( ref $@ ? $@ : "error in ${module}::envs: $@\n" )
+      if $@;
 
     # make copy of environment
     $self->{ENV} = {%{$envs}};
@@ -1536,24 +1535,24 @@ following contexts matches:
 
 =over
 
-=item 0
+=item 1
 
 If called with no arguments (or just an B<Exclude> option,
 as discussed below) return a hashref containing the environment.
 
-=item 1
+=item 2
 
 If called in a scalar context and passed a single variable name
 (which must be a string) return the value for that variable,
 or I<undef> if it is not in the environment.
 
-=item 2
+=item 3
 
 If called in a list context and passed a list of variable names
 (which must be strings) return an array of values for those variables
 (I<undef> for those not in the environment).
 
-=item 3
+=item 4
 
 If called in a scalar context and passed one or more I<match
 specifications>, return a hashref containing the subset
